summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSeoyeon Kim <seoyeon2.kim@samsung.com>2017-09-07 13:25:39 +0900
committerJinho, Lee <jeano.lee@samsung.com>2017-09-28 23:07:24 +0900
commite354600decf4e2e8aafeca6f9d6f8e8575471351 (patch)
treeb4e1ec483f819a6e4e414487b5753a3bec92222a
parentb1de7b9b953d244e6dd5b5bc83f34384fd99e1a6 (diff)
downloadnui-e354600decf4e2e8aafeca6f9d6f8e8575471351.tar.gz
nui-e354600decf4e2e8aafeca6f9d6f8e8575471351.tar.bz2
nui-e354600decf4e2e8aafeca6f9d6f8e8575471351.zip
[Tizen] Add start and end property in PaddingType
- Deprecated Left and Right property in PaddingType - Added Start and End property in PaddingType for multilingual UI framework - Removed x, y, width, and height in PaddingType class Change-Id: I95ff07f9d11b8c57d3a8d486d4678058cefb6ed2 Signed-off-by: Seoyeon Kim <seoyeon2.kim@samsung.com>
-rwxr-xr-xTizen.NUI/src/internal/NDalicPINVOKE.cs28
-rw-r--r--[-rwxr-xr-x]Tizen.NUI/src/public/PaddingType.cs130
2 files changed, 88 insertions, 70 deletions
diff --git a/Tizen.NUI/src/internal/NDalicPINVOKE.cs b/Tizen.NUI/src/internal/NDalicPINVOKE.cs
index ada713d..c757702 100755
--- a/Tizen.NUI/src/internal/NDalicPINVOKE.cs
+++ b/Tizen.NUI/src/internal/NDalicPINVOKE.cs
@@ -5319,23 +5319,17 @@ class NDalicPINVOKE {
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_Set")]
public static extern void PaddingType_Set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2, float jarg3, float jarg4, float jarg5);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_x_set")]
- public static extern void PaddingType_x_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
-
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_x_get")]
- public static extern float PaddingType_x_get(global::System.Runtime.InteropServices.HandleRef jarg1);
-
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_left_set")]
public static extern void PaddingType_left_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_left_get")]
public static extern float PaddingType_left_get(global::System.Runtime.InteropServices.HandleRef jarg1);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_y_set")]
- public static extern void PaddingType_y_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
+ [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_start_set")]
+ public static extern void PaddingType_start_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_y_get")]
- public static extern float PaddingType_y_get(global::System.Runtime.InteropServices.HandleRef jarg1);
+ [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_start_get")]
+ public static extern float PaddingType_start_get(global::System.Runtime.InteropServices.HandleRef jarg1);
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_right_set")]
public static extern void PaddingType_right_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
@@ -5343,11 +5337,11 @@ class NDalicPINVOKE {
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_right_get")]
public static extern float PaddingType_right_get(global::System.Runtime.InteropServices.HandleRef jarg1);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_width_set")]
- public static extern void PaddingType_width_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
+ [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_end_set")]
+ public static extern void PaddingType_end_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_width_get")]
- public static extern float PaddingType_width_get(global::System.Runtime.InteropServices.HandleRef jarg1);
+ [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_end_get")]
+ public static extern float PaddingType_end_get(global::System.Runtime.InteropServices.HandleRef jarg1);
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_bottom_set")]
public static extern void PaddingType_bottom_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
@@ -5355,12 +5349,6 @@ class NDalicPINVOKE {
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_bottom_get")]
public static extern float PaddingType_bottom_get(global::System.Runtime.InteropServices.HandleRef jarg1);
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_height_set")]
- public static extern void PaddingType_height_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
-
- [global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_height_get")]
- public static extern float PaddingType_height_get(global::System.Runtime.InteropServices.HandleRef jarg1);
-
[global::System.Runtime.InteropServices.DllImport("libdali-csharp-binder.so", EntryPoint="CSharp_Dali_PaddingType_top_set")]
public static extern void PaddingType_top_set(global::System.Runtime.InteropServices.HandleRef jarg1, float jarg2);
diff --git a/Tizen.NUI/src/public/PaddingType.cs b/Tizen.NUI/src/public/PaddingType.cs
index b0e3019..f014859 100755..100644
--- a/Tizen.NUI/src/public/PaddingType.cs
+++ b/Tizen.NUI/src/public/PaddingType.cs
@@ -17,6 +17,8 @@
namespace Tizen.NUI
{
+ using System;
+
public class PaddingType : global::System.IDisposable
{
private global::System.Runtime.InteropServices.HandleRef swigCPtr;
@@ -48,6 +50,9 @@ namespace Tizen.NUI
}
}
+ /// <summary>
+ /// Dispose.
+ /// </summary>
public void Dispose()
{
//Throw excpetion if Dispose() is called in separate thread.
@@ -99,6 +104,12 @@ namespace Tizen.NUI
disposed = true;
}
+ /// <summary>
+ /// Equality operator.
+ /// </summary>
+ /// <param name="a">First operand</param>
+ /// <param name="b">Second operand</param>
+ /// <returns>True if the values are identical</returns>
public static bool operator ==(PaddingType a, PaddingType b)
{
// If both are null, or both are same instance, return true.
@@ -120,12 +131,19 @@ namespace Tizen.NUI
(System.Math.Abs(a.Top - b.Top) < NDalic.GetRangedEpsilon(a.Top, b.Top));
}
+ /// <summary>
+ /// Inequality operator.
+ /// </summary>
+ /// <param name="a">First operand</param>
+ /// <param name="b">Second operand</param>
+ /// <returns>True if the values are not identical</returns>
public static bool operator !=(PaddingType a, PaddingType b)
{
return !(a == b);
}
///< The Left value
+ [Obsolete("Please do not use! this will be removed. please use Start instead")]
public float Left
{
set
@@ -138,7 +156,21 @@ namespace Tizen.NUI
}
}
+ ///< The Start value
+ public float Start
+ {
+ set
+ {
+ start = value;
+ }
+ get
+ {
+ return start;
+ }
+ }
+
///< The Right value
+ [Obsolete("Please do not use! this will be removed. please use End instead")]
public float Right
{
set
@@ -151,16 +183,16 @@ namespace Tizen.NUI
}
}
- ///< The Bottom value
- public float Bottom
+ ///< The end value
+ public float End
{
set
{
- bottom = value;
+ end = value;
}
get
{
- return bottom;
+ return end;
}
}
@@ -177,36 +209,50 @@ namespace Tizen.NUI
}
}
-
- public PaddingType() : this(NDalicPINVOKE.new_PaddingType__SWIG_0(), true)
+ ///< The Bottom value
+ public float Bottom
{
- if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
+ set
+ {
+ bottom = value;
+ }
+ get
+ {
+ return bottom;
+ }
}
- public PaddingType(float x, float y, float width, float height) : this(NDalicPINVOKE.new_PaddingType__SWIG_1(x, y, width, height), true)
+ /// <summary>
+ /// Creates an uninitialized PaddingType.
+ /// </summary>
+ public PaddingType() : this(NDalicPINVOKE.new_PaddingType__SWIG_0(), true)
{
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
- public void Set(float newX, float newY, float newWidth, float newHeight)
+ /// <summary>
+ /// PaddingType Constructor.
+ /// </summary>
+ /// <param name="start">Start padding or X coordinate</param>
+ /// <param name="end">End padding or Y coordinate</param>
+ /// <param name="top">Top padding or Height</param>
+ /// <param name="bottom">Bottom padding or Width</param>
+ public PaddingType(float start, float end, float top, float bottom) : this(NDalicPINVOKE.new_PaddingType__SWIG_1(start, end, bottom, top), true)
{
- NDalicPINVOKE.PaddingType_Set(swigCPtr, newX, newY, newWidth, newHeight);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
- private float x
+ /// <summary>
+ /// Assignment from individual values.
+ /// </summary>
+ /// <param name="newStart">Start padding or X coordinate</param>
+ /// <param name="newEnd">End padding or Y coordinate</param>
+ /// <param name="newTop">Top padding or Height</param>
+ /// <param name="newBottom">Bottom padding or Width</param>
+ public void Set(float newStart, float newEnd, float newTop, float newBottom)
{
- set
- {
- NDalicPINVOKE.PaddingType_x_set(swigCPtr, value);
- if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
- }
- get
- {
- float ret = NDalicPINVOKE.PaddingType_x_get(swigCPtr);
- if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
- return ret;
- }
+ NDalicPINVOKE.PaddingType_Set(swigCPtr, newStart, newEnd, newBottom, newTop);
+ if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
private float left
@@ -224,16 +270,16 @@ namespace Tizen.NUI
}
}
- private float y
+ private float start
{
set
{
- NDalicPINVOKE.PaddingType_y_set(swigCPtr, value);
+ NDalicPINVOKE.PaddingType_start_set(swigCPtr, value);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
get
{
- float ret = NDalicPINVOKE.PaddingType_y_get(swigCPtr);
+ float ret = NDalicPINVOKE.PaddingType_start_get(swigCPtr);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
return ret;
}
@@ -254,66 +300,50 @@ namespace Tizen.NUI
}
}
- private float width
+ private float end
{
set
{
- NDalicPINVOKE.PaddingType_width_set(swigCPtr, value);
+ NDalicPINVOKE.PaddingType_end_set(swigCPtr, value);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
get
{
- float ret = NDalicPINVOKE.PaddingType_width_get(swigCPtr);
+ float ret = NDalicPINVOKE.PaddingType_end_get(swigCPtr);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
return ret;
}
}
- private float bottom
- {
- set
- {
- NDalicPINVOKE.PaddingType_bottom_set(swigCPtr, value);
- if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
- }
- get
- {
- float ret = NDalicPINVOKE.PaddingType_bottom_get(swigCPtr);
- if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
- return ret;
- }
- }
-
- private float height
+ private float top
{
set
{
- NDalicPINVOKE.PaddingType_height_set(swigCPtr, value);
+ NDalicPINVOKE.PaddingType_top_set(swigCPtr, value);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
get
{
- float ret = NDalicPINVOKE.PaddingType_height_get(swigCPtr);
+ float ret = NDalicPINVOKE.PaddingType_top_get(swigCPtr);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
return ret;
}
}
- private float top
+ private float bottom
{
set
{
- NDalicPINVOKE.PaddingType_top_set(swigCPtr, value);
+ NDalicPINVOKE.PaddingType_bottom_set(swigCPtr, value);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
}
get
{
- float ret = NDalicPINVOKE.PaddingType_top_get(swigCPtr);
+ float ret = NDalicPINVOKE.PaddingType_bottom_get(swigCPtr);
if (NDalicPINVOKE.SWIGPendingException.Pending) throw NDalicPINVOKE.SWIGPendingException.Retrieve();
return ret;
}
}
-
}
}